<?php
/*
Plugin Name: Lessons "Tabele Create" Part 2
Plugin URI: http://plance.in.ua/plugins
Description: Создание таблицы. Часть 2
Author: Pavel
Author URI: http://plance.in.ua
License: GPL2
Domain Path: /languages
Text Domain: plance
*/

defined('ABSPATH') or die('No script kiddies please!');

/**
 * Подключаем базовый класс
 */
if(class_exists('WP_List_Table') == FALSE)
{
    require_once(ABSPATH.'wp-admin/includes/class-wp-list-table.php');
}

/**
 * Отображаем таблицу лишь в том случае, если пользователь администратор
 */
if(is_admin() == TRUE)
{
    new Plance_INIT_Lessons2();
}
 
/**
 * Класс формирующий пункт меню и отображающий таблицу
 */
class Plance_INIT_Lessons2
{
	private $_Table;
	
    /**
     * Конструктор
     */
    public function __construct()
    {
        add_action('admin_menu', array($this, 'createMenu'));
		add_filter('set-screen-option', array($this, 'setScreenOption'), 10, 3);
		add_action('admin_head', array($this, 'adminHead'));
		add_action('plugins_loaded', array($this, 'loadTextdomain'));
    }
 
    /**
     * Создает пункт меню
     */
    public function createMenu()
    {
        $hook = add_menu_page(
			'Table', 
			'Table', 
			'manage_options', 
			__CLASS__, 
			array($this, 'createTable')
		);
		
		add_action('load-'.$hook, array($this, 'showScreenOptions'));
    }
 
	/**
	 * Устанавливаем (сохраняем) настройки экрана
	 */
	public function setScreenOption($status, $option, $value)
	{
		if('plance_per_page' == $option )
		{
			return $value;
		}

		return $status;
	}
	
	/**
	 * Настраиваем стили
	 */
	public function adminHead()
	{
		if(__CLASS__ == (isset($_GET['page']) ? esc_attr($_GET['page']) : ''))
		{
			echo '<style type="text/css">';
			echo '.wp-list-table .column-cb { width: 4%; }';
			echo '.wp-list-table .column-ex_id { width: 5%; }';
			echo '.wp-list-table .column-ex_title { width: 30%; }';
			echo '.wp-list-table .column-ex_author { width: 15%; }';
			echo '.wp-list-table .column-ex_description { width: 36%; }';
			echo '.wp-list-table .column-ex_price { width: 10%; }';
			echo '</style>';
		}
	}
	
	/**
	 * Подключаем языки
	 */
	public function loadTextdomain()
	{
		load_plugin_textdomain('plance', false, basename(__DIR__).'/languages/'); 
	}
	
	/**
	 * Создаем настройки экрана
	 */
	public function showScreenOptions()
	{
		add_screen_option('per_page', array(
			'label' => __('Records', 'plance'),
			'default' => 10,
			'option' => 'plance_per_page'
		));
		
		get_current_screen() -> add_help_tab(array(
			'id'		=> 'plance-tab-1',
			'title'		=> __('Tab 1', 'plance'),
			'content'	=> '<p>'.__('Content 1', 'plance').'</p>',
		));
		get_current_screen() -> add_help_tab(array(
			'id'		=> 'plance-tab-2',
			'title'		=> __('Tab 2', 'plance'),
			'content'	=> '<p>'.__('Content 2', 'plance').'</p>',
		));
		
		$this -> _Table = new Plance_Table_Lessons2();
	}
	
    /**
     * Отображает таблицу
     *
     */
    public function createTable()
    {
        $this -> _Table -> prepare_items();
        ?>
            <div class="wrap">
                <h2><?php echo __('Example List Table', 'plance')?></h2>
				<form method="get">
					<input type="hidden" name="page" value="<?php echo __CLASS__ ?>" />
					<?php $this -> _Table -> search_box('search', 'search_id'); ?>
					<?php $this -> _Table -> display(); ?>
				</form>
            </div>
        <?php
    }
}
 
/**
 * Класс создающий таблицу
 */
class Plance_Table_Lessons2 extends WP_List_Table
{
    /**
     * Подготавливаем колонки таблицы для их отображения
     *
     */
    public function prepare_items()
    {
		/* Получаем текущее значение action */
		$action = $this -> current_action();
		
		//===========================================================
		
		//Sets
		$per_page = $this -> get_items_per_page('plance_per_page', 10);
		
		/* Получаем данные для формирования таблицы */
        $data = $this -> table_data();
 
		/* Устанавливаем данные для пагинации */
        $this -> set_pagination_args( array(
            'total_items' => count($data),
            'per_page'    => $per_page
        ));
 
		/* Делим массив на части для пагинации */
        $data = array_slice(
			$data,
			(($this -> get_pagenum() - 1) * $per_page),
			$per_page
		);
 
//		/* Устанавливаем данные колонок */
//		$this -> _column_headers = array(
//			$this -> get_columns(), /* Получаем массив названий колокнок */
//			$this -> get_hidden_columns(), /* Получаем массив названий колонок которые нужно скрыть */
//			$this -> get_sortable_columns() /* Получаем массив названий колонок которые можно сортировать */
//		);

		$this -> _column_headers = $this -> get_column_info();
		
		/* Устанавливаем данные таблицы */
        $this -> items = $data;
    }
 
    /**
     * Название колонок таблицы
     *
     * @return array
     */
    public function get_columns()
    {
        return array(
			'cb'			=> '<input type="checkbox" />',
            'ex_id'			=> __('ID', 'plance'),
            'ex_title'		=> __('Title', 'plance'),
            'ex_author'		=> __('Author', 'plance'),
            'ex_description'=> __('Description', 'plance'),
            'ex_price'		=> __('Price', 'plance'),
        );
    }
 
    /**
     * Массив колонок которые нужно скрыть
     *
     * @return array
     */
    public function get_hidden_columns()
    {
        return array();
    }
 
    /**
     * Массив названий колонок по которым выполняется сортировка
     *
     * @return array
     */
    public function get_sortable_columns()
    {
        return array(
			'ex_id'		=> array('ex_id', false),
			'ex_title'	=> array('ex_title', true),
			'ex_author' => array('ex_author', false),
			'ex_price'	=> array('ex_price', false),
		);
    }
 
    /**
     * Данные таблицы
     *
     * @return array
     */
    private function table_data()
    {
        return array(
			array(
				'ex_id'			=> 1,
				'ex_title'		=> 'Уличный кот по имени Боб',
				'ex_author'		=> 'Боуэн Джеймс',
				'ex_description'=> 'Мировой бестселлер!Готовится экранизация! Он был одиноким бездомным музыкантом, но увидел на',
				'ex_price'		=> '61,00',
			),
			array(
				'ex_id'			=> 2,
				'ex_title'		=> 'Святые иконы. Как правильно просить',
				'ex_author'		=> '',
				'ex_description'=> 'Когда человек в отчаянии, он перед иконами обращает свои молитвы к святым заступникам. Но не все знают...',
				'ex_price'		=> '38,80',
			),
			array(
				'ex_id'			=> 3,
				'ex_title'		=> 'До встречи с тобой',
				'ex_author'		=> 'Мойес Джоджо',
				'ex_description'=> 'Впервые на русском языке! Книга вошла в список бестселлеров «Нью-Йорк таймс», переведена на 31 язык...',
				'ex_price'		=> '60,50',
			),
			array(
				'ex_id'			=> 4,
				'ex_title'		=> 'Искусство войны',
				'ex_author'		=> 'Сунь Цзы',
				'ex_description'=> 'Один из самых известных трудов древности! Этот трактат не утратил своей актуальности за 2500 лет!..',
				'ex_price'		=> '111,00',
			),
			array(
				'ex_id'			=> 5,
				'ex_title'		=> 'Дім дивних дітей',
				'ex_author'		=> 'Риггз Ренсом',
				'ex_description'=> 'Інтригуюча історія, що зацікавила кращих режисерів Голлівуду!Таємничий острів. Покинутий притулок. П...',
				'ex_price'		=> '35,40',
			),
			array(
				'ex_id'			=> 6,
				'ex_title'		=> 'Я вижу вас насквозь. Научитесь читать человека к',
				'ex_author'		=> 'Мессинджер Жозеф',
				'ex_description'=> 'Авторы с многолетним стажем изучения жестов человека раскрывают тайны языка тела! Собеседник не смо...',
				'ex_price'		=> '44,30',
			),
			array(
				'ex_id'			=> 7,
				'ex_title'		=> 'Салаты. Овощные. Мясные',
				'ex_author'		=> 'Гагарина А',
				'ex_description'=> 'Коллекция из более чем 400 вкусных салатов, легких в приготовлении!Разнообразные по вкусу и сочетани...',
				'ex_price'		=> '39,90',
			),
			array(
				'ex_id'			=> 8,
				'ex_title'		=> 'Зона покриття',
				'ex_author'		=> 'Кинг Стивен',
				'ex_description'=> 'Якщо хтось і здатний написати Великий Містичний Роман-Катастрофу, то це — Стівен Кінг, найуспішніший...',
				'ex_price'		=> '44,30',
			),
			array(
				'ex_id'			=> 9,
				'ex_title'		=> 'Українська вишивка: Рушники',
				'ex_author'		=> '',
				'ex_description'=> 'Українське — це модно! Українська вишивка зачаровує і привертає до себе увагу в усьому світі...',
				'ex_price'		=> '55,40',
			),
			array(
				'ex_id'			=> 10,
				'ex_title'		=> 'Під Куполом',
				'ex_author'		=> 'Кинг Стивен',
				'ex_description'=> 'Осінньої днини на містечко Честер Мілл опустився прозорий Купол, через який неможливо пройти...',
				'ex_price'		=> '89,90',
			),
			array(
				'ex_id'			=> 11,
				'ex_title'		=> 'Втрачений символ',
				'ex_author'		=> 'Браун Дэн',
				'ex_description'=> 'Світовий бестселер! На межі життя та смерті Ленґдон розгадує секрет масонів. Але чи потрібно людям знати його?',
				'ex_price'		=> '44,30',
			),
			array(
				'ex_id'			=> 12,
				'ex_title'		=> 'КАРТИ. Ілюстрована мандрівка',
				'ex_author'		=> 'Мізелінські Олександра і...',
				'ex_description'=> 'Ця книга запрошує у захоплюючу навколосвітню подорож. Ви побачите могутні гейзери Ісландії, довгі ка...',
				'ex_price'		=> '241,00',
			),
			array(
				'ex_id'			=> 13,
				'ex_title'		=> 'Кульбабове вино',
				'ex_author'		=> 'Брэдбери Рэй',
				'ex_description'=> 'Події повісті Рея Бредбері «Кульбабове вино» розгортаються влітку 1928 року у вигаданому містечку Гр… ',
				'ex_price'		=> '45,90',
			),
		);
    }
 
	public function no_items()
	{
	  echo __('Data not found', 'plance');
	}
	
    /**
     * Возвращает содержимое колонки
     *
     * @param  array $item массив данных таблицы
     * @param  string $column_name название текущей колонки
     *
     * @return mixed
     */
    public function column_default($item, $column_name )
    {
        switch($column_name)
		{
			case 'ex_id':
			case 'ex_author':
			case 'ex_description':
			case 'ex_price':
				return $item[$column_name];
            default:
				return print_r($item, true);
        }
    }
	
	/**
	 * Создает чекбокс
	 * @param array $item
	 * @return string
	 */
	function column_cb($item)
	{
		return '<input type="checkbox" name="id[]" value="'.$item['ex_id'].'" />';
	}
	
	/**
	 * Формируем для записей колонки "title" дополнительные ссылки
	 * @param array $item
	 * @return string
	 */
	function column_ex_title($item)
	{
		return $item['ex_title'].' '.$this -> row_actions(array(
			'edit'	 => '<a href="?page='.$_REQUEST['page'].'&action=edit&book='.$item['ex_id'].'">редактировать</a>',
			'delete' => '<a href="?page='.$_REQUEST['page'].'&action=delete&book='.$item['ex_id'].'">удалить</a>',
		));
	}
	
	/**
	 * Возвращает массив опций для групповых действий
	 * @return array
	 */
	function get_bulk_actions()
	{
		return array(
			'delete' => __('delete', 'plance'),
			'lock' => __('lock', 'plance'),
			'unlock' => __('unlock', 'plance'),
		);
	}
}